==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/client/integration/jei/PureDaisyRecipeCategory.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.integration.jei;

import com.mojang.blaze3d.systems.RenderSystem;
import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.builder.IRecipeSlotBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.ingredient.IRecipeSlotsView;
import mezz.jei.api.helpers.IGuiHelper;
import mezz.jei.api.helpers.IPlatformFluidHelper;
import mezz.jei.api.recipe.IFocusGroup;
import mezz.jei.api.recipe.RecipeIngredientRole;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.recipe.category.IRecipeCategory;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_3610;
import net.minecraft.class_4587;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.recipe.PureDaisyRecipe;
import vazkii.botania.api.recipe.StateIngredient;
import vazkii.botania.common.block.BotaniaFlowerBlocks;
import vazkii.botania.common.lib.LibMisc;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class PureDaisyRecipeCategory implements IRecipeCategory<PureDaisyRecipe> {

	public static final RecipeType<PureDaisyRecipe> TYPE = RecipeType.create(LibMisc.MOD_ID, "pure_daisy", PureDaisyRecipe.class);
	private final IDrawable background;
	private final class_2561 localizedName;
	private final IDrawable overlay;
	private final IDrawable icon;
	@SuppressWarnings("rawtypes")
	private final IPlatformFluidHelper fluidHelper;

	public PureDaisyRecipeCategory(IGuiHelper guiHelper, IPlatformFluidHelper<?> fluidHelper) {
		background = guiHelper.createBlankDrawable(96, 44);
		localizedName = class_2561.method_43471("botania.nei.pureDaisy");
		overlay = guiHelper.createDrawable(prefix("textures/gui/pure_daisy_overlay.png"),
				0, 0, 64, 44);
		icon = guiHelper.createDrawableIngredient(VanillaTypes.ITEM_STACK, new class_1799(BotaniaFlowerBlocks.pureDaisy));
		this.fluidHelper = fluidHelper;
	}

	@NotNull
	@Override
	public RecipeType<PureDaisyRecipe> getRecipeType() {
		return TYPE;
	}

	@NotNull
	@Override
	public class_2561 getTitle() {
		return localizedName;
	}

	@NotNull
	@Override
	public IDrawable getBackground() {
		return background;
	}

	@NotNull
	@Override
	public IDrawable getIcon() {
		return icon;
	}

	@Override
	public void draw(PureDaisyRecipe recipe, IRecipeSlotsView slotsView, class_4587 ms, double mouseX, double mouseY) {
		RenderSystem.enableBlend();
		overlay.draw(ms, 17, 0);
		RenderSystem.disableBlend();
	}

	@SuppressWarnings("unchecked")
	@Override
	public void setRecipe(@NotNull IRecipeLayoutBuilder builder, @NotNull PureDaisyRecipe recipe, @NotNull IFocusGroup focusGroup) {
		StateIngredient input = recipe.getInput();

		IRecipeSlotBuilder inputSlotBuilder = builder.addSlot(RecipeIngredientRole.INPUT, 9, 12)
				.setFluidRenderer(1000, false, 16, 16);
		for (var state : input.getDisplayed()) {
			if (!state.method_26227().method_15769()) {
				inputSlotBuilder.addIngredient(this.fluidHelper.getFluidIngredientType(),
						this.fluidHelper.create(state.method_26227().method_15772(), 1000));
			}
		}
		inputSlotBuilder.addItemStacks(input.getDisplayedStacks())
				.addTooltipCallback((view, tooltip) -> tooltip.addAll(input.descriptionTooltip()));

		builder.addSlot(RecipeIngredientRole.CATALYST, 39, 12)
				.addItemStack(new class_1799(BotaniaFlowerBlocks.pureDaisy));

		class_2248 outBlock = recipe.getOutputState().method_26204();
		class_3610 outFluid = outBlock.method_9564().method_26227();
		if (!outFluid.method_15769()) {
			builder.addSlot(RecipeIngredientRole.OUTPUT, 68, 12)
					.setFluidRenderer(1000, false, 16, 16)
					.addIngredient(this.fluidHelper.getFluidIngredientType(),
							this.fluidHelper.create(outFluid.method_15772(), 1000));
		} else {
			if (outBlock.method_8389() != class_1802.field_8162) {
				builder.addSlot(RecipeIngredientRole.OUTPUT, 68, 12)
						.addItemStack(new class_1799(outBlock));
			}
		}
	}
}

==> Botania-1.20.1-451-FABRIC-20251019.112919-17-sources.jar: vazkii/botania/client/integration/jei/PureDaisyRecipeCategory.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.integration.jei;

import com.mojang.blaze3d.systems.RenderSystem;

import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.builder.IRecipeSlotBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.ingredient.IRecipeSlotsView;
import mezz.jei.api.helpers.IGuiHelper;
import mezz.jei.api.helpers.IPlatformFluidHelper;
import mezz.jei.api.recipe.IFocusGroup;
import mezz.jei.api.recipe.RecipeIngredientRole;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.recipe.category.IRecipeCategory;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_332;
import net.minecraft.class_3610;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.recipe.PureDaisyRecipe;
import vazkii.botania.api.recipe.StateIngredient;
import vazkii.botania.common.block.BotaniaFlowerBlocks;
import vazkii.botania.common.lib.LibMisc;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class PureDaisyRecipeCategory implements IRecipeCategory<PureDaisyRecipe> {

	public static final RecipeType<PureDaisyRecipe> TYPE = RecipeType.create(LibMisc.MOD_ID, "pure_daisy", PureDaisyRecipe.class);
	private final IDrawable background;
	private final class_2561 localizedName;
	private final IDrawable overlay;
	private final IDrawable icon;
	@SuppressWarnings("rawtypes")
	private final IPlatformFluidHelper fluidHelper;

	public PureDaisyRecipeCategory(IGuiHelper guiHelper, IPlatformFluidHelper<?> fluidHelper) {
		background = guiHelper.createBlankDrawable(96, 44);
		localizedName = class_2561.method_43471("botania.nei.pureDaisy");
		overlay = guiHelper.createDrawable(prefix("textures/gui/pure_daisy_overlay.png"),
				0, 0, 64, 44);
		icon = guiHelper.createDrawableIngredient(VanillaTypes.ITEM_STACK, new class_1799(BotaniaFlowerBlocks.pureDaisy));
		this.fluidHelper = fluidHelper;
	}

	@NotNull
	@Override
	public RecipeType<PureDaisyRecipe> getRecipeType() {
		return TYPE;
	}

	@NotNull
	@Override
	public class_2561 getTitle() {
		return localizedName;
	}

	@NotNull
	@Override
	public IDrawable getBackground() {
		return background;
	}

	@NotNull
	@Override
	public IDrawable getIcon() {
		return icon;
	}

	@Override
	public void draw(PureDaisyRecipe recipe, IRecipeSlotsView slotsView, class_332 gui, double mouseX, double mouseY) {
		RenderSystem.enableBlend();
		overlay.draw(gui, 17, 0);
		RenderSystem.disableBlend();
	}

	@SuppressWarnings("unchecked")
	@Override
	public void setRecipe(@NotNull IRecipeLayoutBuilder builder, @NotNull PureDaisyRecipe recipe, @NotNull IFocusGroup focusGroup) {
		StateIngredient input = recipe.getInput();

		IRecipeSlotBuilder inputSlotBuilder = builder.addSlot(RecipeIngredientRole.INPUT, 9, 12)
				.setFluidRenderer(1000, false, 16, 16);
		for (var state : input.getDisplayed()) {
			if (!state.method_26227().method_15769()) {
				inputSlotBuilder.addIngredient(this.fluidHelper.getFluidIngredientType(),
						this.fluidHelper.create(state.method_26227().method_15772(), 1000));
			}
		}
		inputSlotBuilder.addItemStacks(input.getDisplayedStacks())
				.addTooltipCallback((view, tooltip) -> tooltip.addAll(input.descriptionTooltip()));

		builder.addSlot(RecipeIngredientRole.CATALYST, 39, 12)
				.addItemStack(new class_1799(BotaniaFlowerBlocks.pureDaisy));

		class_2248 outBlock = recipe.getOutputState().method_26204();
		class_3610 outFluid = outBlock.method_9564().method_26227();
		if (!outFluid.method_15769()) {
			builder.addSlot(RecipeIngredientRole.OUTPUT, 68, 12)
					.setFluidRenderer(1000, false, 16, 16)
					.addIngredient(this.fluidHelper.getFluidIngredientType(),
							this.fluidHelper.create(outFluid.method_15772(), 1000));
		} else {
			if (outBlock.method_8389() != class_1802.field_8162) {
				builder.addSlot(RecipeIngredientRole.OUTPUT, 68, 12)
						.addItemStack(new class_1799(outBlock));
			}
		}
	}
}
